@@ -1,8 +1,8 @@
 import requests
 import json
+from janda.utils.parser import Api
 
-BASE_URL = 'https://scathach.redsplit.org/v4/pururin/'
-
+BASE_URL = Api()
 
 class Pururin(object):
     """
@@ -10,26 +10,24 @@ class Pururin(object):
 
     """
     @staticmethod
-    def better_object(parser):
+    def better_object(parser: dict):
         """Converts the json object to a more readable object.
 
         Parameters
         ----------
         parser : dict
             The json object.
-
         """
         return json.dumps(parser, sort_keys=True, indent=4)
 
     @staticmethod
-    def auto_space(string):
+    def auto_space(string: str):
         """Automatically adds spaces for GET requests
 
         Parameters
         ----------
         string : str
             The string to be formatted.
-
         """
 
         return string.replace(' ', '+')
@@ -41,7 +39,6 @@ class Pururin(object):
         ----------
         api_key : str
             scathach.dev API key (optional)
-
         """
         if api_key is '':
             self.api_key = None
@@ -49,7 +46,7 @@ class Pururin(object):
             self.api_key = api_key
         self.specs = {'api_key': self.api_key}
 
-    def get_book(self, book: int):
+    async def get(self, book: int):
         """Get doujin API from Id
 
         path: https://pururin.to/gallery/61119
@@ -78,13 +75,15 @@ class Pururin(object):
         except ValueError:
             raise ValueError('Book must be an int')
 
-        data = requests.get(BASE_URL, params=self.specs)
+        data = requests.get(BASE_URL.pururin, params=self.specs)
         if data.json()['type'] is None:
             raise ValueError('No results found')
 
-        return Pururin.better_object(data.json())
+        self.final = json.loads(Pururin.better_object(data.json()), encoding="utf-8")
 
-    def search_by_newest(self, query: str):
+        return Pururin.better_object(self.final)
+
+    async def search_by_newest(self, query: str):
         """Search for doujin based on newest 
 
         path: https://pururin.to/search/most-popular?q=alter
@@ -111,7 +110,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -119,7 +118,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def search_by_most_popular(self, query: str):
+    async def search_by_most_popular(self, query: str):
         """Search doujins by most popular
 
         path: https://pururin.to/search/most-popular?q=alter
@@ -146,7 +145,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -154,7 +153,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def search_by_highest_rated(self, query: str):
+    async def search_by_highest_rated(self, query: str):
         """Search for doujin based on the highest rated
 
         path: https://pururin.to/search/highest-rated?q=alter
@@ -181,7 +180,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -189,7 +188,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def search_by_most_viewed(self, query: str):
+    async def search_by_most_viewed(self, query: str):
         """Search for doujin based on the most viewed
 
         path: https://pururin.to/search/most-viewed?q=alter
@@ -216,7 +215,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -224,7 +223,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def search_by_title(self, query: str):
+    async def search_by_title(self, query: str):
         """Search for doujin based on title
 
         path: https://pururin.to/search/title?q=alter
@@ -251,7 +250,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -259,7 +258,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def search_by_random(self, query: str):
+    async def search_by_random(self, query: str):
         """Search for doujin based on random
 
         path: https://pururin.to/search/random?q=alter
@@ -286,7 +285,7 @@ class Pururin(object):
 
         if query is '':
             raise ValueError('Query must be given')
-        data = requests.get(BASE_URL + 'args.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)
 
         # if data.json() length is 0, then throw error
         if len(data.json()) == 0:
@@ -294,7 +293,7 @@ class Pururin(object):
 
         return Pururin.better_object(data.json())
 
-    def get_random(self):
+    async def get_random(self):
         """Gets random doujin on pururin
 
         Returns
@@ -302,11 +301,11 @@ class Pururin(object):
         dict
             The book object that represents the doujin response.
         """
-        data = requests.get(BASE_URL + 'random' + '/', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'random' + '/', params=self.specs)
 
         return Pururin.better_object(data.json())
 
-    def get_random_with_query(self, query: str):
+    async def get_random_with_query(self, query: str):
         """Gets doujin on pururin by query
 
         path: https://pururin.to/search?q=alter
@@ -329,7 +328,7 @@ class Pururin(object):
 
         self.specs['p'] = query
         query = Pururin.auto_space(query)
-        data = requests.get(BASE_URL + 'search.php', params=self.specs)
+        data = requests.get(BASE_URL.pururin + 'search.php', params=self.specs)
 
         # if result null, then throw error
         if data.json()['type'] is None:
